@@ -1,5 +1,7 @@
 pub(crate) mod func;
+pub(crate) mod interval;
 pub(crate) mod types;
 
 pub use func::*;
+pub use interval::*;
 pub use types::*;
